You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by js...@apache.org on 2004/10/19 23:36:21 UTC

svn commit: rev 55102 - in incubator/beehive/trunk/controls/test: src/controls/org/apache/beehive/controls/test/controls/property src/drivers/org/apache/beehive/controls/test/driver/property src/units/org/apache/beehive/controls/test/java/property webapps/controlsWeb/property/client_access webapps/controlsWeb/property/client_access2 webapps/controlsWeb/property/client_impl webapps/controlsWeb/property/client_impl2 webapps/controlsWeb/property/impl_access webapps/controlsWeb/property/impl_access2

Author: jsong
Date: Tue Oct 19 14:36:21 2004
New Revision: 55102

Added:
   incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/PropertyControl.java   (contents, props changed)
   incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/PropertyControlImpl.jcs   (contents, props changed)
   incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveContextAccess.java   (contents, props changed)
   incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveGetters.java   (contents, props changed)
   incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveSetters.java   (contents, props changed)
Removed:
   incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/SingleProperty.java
   incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/SingleProperty2.java
   incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/SingleProperty2Impl.jcs
   incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/SinglePropertyImpl.jcs
   incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveClientAccess.java
   incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveClientImpl.java
   incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveImplAccess.java
Modified:
   incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientAccessTest.java
   incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientImplTest.java
   incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ImplAccessTest.java
   incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access/Controller.jpf
   incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access2/Controller.jpf
   incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl/Controller.jpf
   incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl2/Controller.jpf
   incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access/Controller.jpf
   incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access2/Controller.jpf
Log:
Revise tests on controls property. Add tests for propertySet with prefix, remove unused controls, update test drivers.
Code reviewed by Alek.
Checkin.tests passed.


Added: incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/PropertyControl.java
==============================================================================
--- (empty file)
+++ incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/PropertyControl.java	Tue Oct 19 14:36:21 2004
@@ -0,0 +1,35 @@
+package org.apache.beehive.controls.test.controls.property;
+
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import org.apache.beehive.controls.api.bean.ControlInterface;
+import org.apache.beehive.controls.api.properties.PropertySet;
+
+/**
+ * A control interface with multiple propertySets declared
+ */
+@ControlInterface
+public interface PropertyControl
+{
+	static final String DEFAULT_ATTRIBUTE_VALUE1 = "Hello";
+	static final String DEFAULT_ATTRIBUTE_VALUE3 = "Hello3";
+
+	@PropertySet
+	@Retention(RetentionPolicy.RUNTIME)
+	public @interface PropertyOne
+	{
+		public String attribute1() default DEFAULT_ATTRIBUTE_VALUE1;
+		public String attribute2();
+    }
+
+	@PropertySet(prefix="PropertyTwo")
+	@Retention(RetentionPolicy.RUNTIME)
+	public @interface PropertyTwo
+	{
+		public String attribute3() default DEFAULT_ATTRIBUTE_VALUE3;
+		public String attribute4();
+    }
+
+	public String getAttribute1ByContext();
+	public String getAttribute3ByContext();
+}

Added: incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/PropertyControlImpl.jcs
==============================================================================
--- (empty file)
+++ incubator/beehive/trunk/controls/test/src/controls/org/apache/beehive/controls/test/controls/property/PropertyControlImpl.jcs	Tue Oct 19 14:36:21 2004
@@ -0,0 +1,33 @@
+package org.apache.beehive.controls.test.controls.property;
+
+import org.apache.beehive.controls.api.bean.ControlImplementation;
+import org.apache.beehive.controls.api.context.Context;
+import org.apache.beehive.controls.api.context.ControlBeanContext;
+
+/**
+ * A control impl that accesses the property declared by its control interface via control context
+ */
+
+@ControlImplementation
+public class PropertyControlImpl implements PropertyControl
+{ 
+    @Context ControlBeanContext context;
+
+    /*Accesses the propertySet value and returns the value*/
+    public String getAttribute1ByContext()
+    {
+    	/**BUG: could not refer to Greeting directly*/
+        PropertyOne propertyOne=(PropertyControl.PropertyOne)context.getControlPropertySet(PropertyControl.PropertyOne.class);
+        
+        return propertyOne.attribute1();
+    }
+
+    /*Accesses the propertySet value and returns the value*/
+    public String getAttribute3ByContext()
+    {
+    	/**BUG: could not refer to Greeting directly*/
+        PropertyTwo propertyTwo=(PropertyControl.PropertyTwo)context.getControlPropertySet(PropertyControl.PropertyTwo.class);
+        
+        return propertyTwo.attribute3();
+    }
+} 
\ No newline at end of file

Added: incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveContextAccess.java
==============================================================================
--- (empty file)
+++ incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveContextAccess.java	Tue Oct 19 14:36:21 2004
@@ -0,0 +1,42 @@
+package org.apache.beehive.controls.test.driver.property;
+
+import org.apache.beehive.test.tools.milton.common.Report;
+import org.apache.beehive.controls.test.controls.property.PropertyControl;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+
+/*
+ * Tests getting control properties using control context.
+ */
+
+public class DriveContextAccess
+{
+	private PropertyControlBean myControl;
+
+	public void setControl(PropertyControlBean aControl){
+
+		myControl=aControl;
+	}
+
+	public Report doTest(){
+
+		Report report=new Report();
+
+		if (myControl==null){
+			report.setStatus(Report.FAIL);
+			report.setMessage("the control is NULL");
+		}
+		else
+		{
+			String attribute1=myControl.getAttribute1ByContext();
+			String attribute3=myControl.getAttribute3ByContext();
+			if ((attribute1.equals(PropertyControl.DEFAULT_ATTRIBUTE_VALUE1))&&
+				(attribute3.equals(PropertyControl.DEFAULT_ATTRIBUTE_VALUE3)))
+				report.setStatus(Report.PASS);
+			else{
+				report.setStatus(Report.FAIL);
+				report.setMessage("Attribute1:"+attribute1+". Attribute3:"+attribute3);
+			}
+		}
+		return report;
+	}
+}

Added: incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveGetters.java
==============================================================================
--- (empty file)
+++ incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveGetters.java	Tue Oct 19 14:36:21 2004
@@ -0,0 +1,42 @@
+package org.apache.beehive.controls.test.driver.property;
+
+import org.apache.beehive.test.tools.milton.common.Report;
+import org.apache.beehive.controls.test.controls.property.PropertyControl;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+
+/* Tests getting property values using getters on control bean class
+ */
+public class DriveGetters
+{
+	private PropertyControlBean myControl;
+
+	public void setControl(PropertyControlBean aControl){
+
+		myControl=aControl;
+	}
+
+	public Report doTest(){
+
+		Report report=new Report();
+
+		if (myControl==null){
+			report.setStatus(Report.FAIL);
+			report.setMessage("the control is NULL");
+		}
+		else
+		{
+			String attribute1=myControl.getAttribute1();
+			String attribute3=myControl.getPropertyTwoAttribute3();
+
+			if ((attribute1.equals(PropertyControl.DEFAULT_ATTRIBUTE_VALUE1))&&
+				(attribute3.equals(PropertyControl.DEFAULT_ATTRIBUTE_VALUE3)))
+				report.setStatus(Report.PASS);
+			else{
+				report.setStatus(Report.FAIL);
+				report.setMessage("Attribute1:"+attribute1+". Attribute3"+attribute3);
+			}
+		}
+		return report;
+	}
+
+}

Added: incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveSetters.java
==============================================================================
--- (empty file)
+++ incubator/beehive/trunk/controls/test/src/drivers/org/apache/beehive/controls/test/driver/property/DriveSetters.java	Tue Oct 19 14:36:21 2004
@@ -0,0 +1,45 @@
+package org.apache.beehive.controls.test.driver.property;
+
+import org.apache.beehive.test.tools.milton.common.Report;
+import org.apache.beehive.controls.test.controls.property.PropertyControl;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+
+/* Tests setting property values using setters on control bean class
+ */
+public class DriveSetters
+{
+	private PropertyControlBean myControl;
+
+	public void setControl(PropertyControlBean aControl){
+
+		myControl=aControl;
+	}
+
+	public Report doTest(){
+
+		Report report=new Report();
+
+		if (myControl==null){
+			report.setStatus(Report.FAIL);
+			report.setMessage("the control is NULL");
+		}
+		else
+		{
+			myControl.setAttribute1("New value for attribute1");
+			myControl.setPropertyTwoAttribute3("New value for attribute3");
+
+			String newAttribute1=myControl.getAttribute1ByContext();
+			String newAttribute3=myControl.getAttribute3ByContext();
+
+			if ((newAttribute1.equals("New value for attribute1"))&&
+				(newAttribute3.equals("New value for attribute3")))
+				report.setStatus(Report.PASS);
+			else{
+				report.setStatus(Report.FAIL);
+				report.setMessage("newAttribute1:"+newAttribute1+". newAttribute3"+newAttribute3);
+			}
+		}
+		return report;
+	}
+
+}

Modified: incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientAccessTest.java
==============================================================================
--- incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientAccessTest.java	(original)
+++ incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientAccessTest.java	Tue Oct 19 14:36:21 2004
@@ -5,8 +5,8 @@
 import java.beans.Beans;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveClientAccess;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveGetters;
 import org.apache.beehive.test.tools.mantis.annotations.tch.Freq;
 import org.apache.beehive.test.tools.mantis.annotations.tch.Status;
 import org.apache.beehive.test.tools.milton.common.Report;
@@ -23,9 +23,7 @@
 	 * A control that declares some propertySet in its control interface
 	 */
     @Control
-    public SinglePropertyBean myControl;
-
-	/** BUG: getter/setter in generated bean is busted. comment out all tests using getter/setter*/
+    public PropertyControlBean myControl;
 
     /**
      * Accesses property value by getter of the control bean instance.
@@ -37,7 +35,7 @@
     {
 		/*
 		Report report=new Report();
-		DriveClientAccess driver=new DriveClientAccess();
+		DriveGetters driver=new DriveGetters();
 		driver.setControl(myControl);
 		report=driver.doTest();
 		String result=report.getStatus();
@@ -55,10 +53,10 @@
     public void testGetterByProgram() throws Exception
     {
 		Report report=new Report();
-		SinglePropertyBean sbean=(SinglePropertyBean)Beans.instantiate(
+		PropertyControlBean sbean=(PropertyControlBean)Beans.instantiate(
 			Thread.currentThread().getContextClassLoader(),
-            "org.apache.beehive.controls.test.controls.property.SinglePropertyBean");
-		DriveClientAccess driver=new DriveClientAccess();
+            "org.apache.beehive.controls.test.controls.property.PropertyControlBean");
+		DriveGetters driver=new DriveGetters();
 		driver.setControl(sbean);
 		report=driver.doTest();
 		String result=report.getStatus();

Modified: incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientImplTest.java
==============================================================================
--- incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ImplAccessTest.java	(original)
+++ incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ImplAccessTest.java	Tue Oct 19 14:36:21 2004
@@ -4,8 +4,8 @@
 import java.beans.Beans;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveImplAccess;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveContextAccess;
 import org.apache.beehive.test.tools.mantis.annotations.tch.Freq;
 import org.apache.beehive.test.tools.mantis.annotations.tch.Status;
 import org.apache.beehive.test.tools.milton.common.Report;
@@ -24,7 +24,7 @@
  	 * It has a method that allow accessing these property values via control context.
 	 */
     @Control
-    public SinglePropertyBean myControl;
+    public PropertyControlBean myControl;
 
 
     /**
@@ -38,7 +38,7 @@
     {
 
 		Report report=new Report();
-		DriveImplAccess driver=new DriveImplAccess();
+		DriveContextAccess driver=new DriveContextAccess();
 		driver.setControl(myControl);
 		report=driver.doTest();
 		String result=report.getStatus();
@@ -56,9 +56,10 @@
     public void testContextAccessByProgram() throws Exception
     {
 		Report report=new Report();
-		SinglePropertyBean sbean=(SinglePropertyBean)Beans.instantiate(Thread.currentThread().getContextClassLoader(),
-                                 "org.apache.beehive.controls.test.controls.property.SinglePropertyBean");
-		DriveImplAccess driver=new DriveImplAccess();
+		PropertyControlBean sbean=(PropertyControlBean)Beans.instantiate(
+			Thread.currentThread().getContextClassLoader(),
+            "org.apache.beehive.controls.test.controls.property.PropertyControlBean");
+		DriveContextAccess driver=new DriveContextAccess();
 		driver.setControl(sbean);
 		report=driver.doTest();
 		String result=report.getStatus();

Modified: incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access/Controller.jpf
==============================================================================
--- incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access/Controller.jpf	(original)
+++ incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access/Controller.jpf	Tue Oct 19 14:36:21 2004
@@ -24,8 +24,8 @@
 
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveClientAccess;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveGetters;
 import org.apache.beehive.test.tools.milton.common.Report;
 
 /* Tests client getting control property via getter/setter on control bean
@@ -39,7 +39,7 @@
 public class Controller extends PageFlowController
 {
     @Control
-    public SinglePropertyBean myControl;
+    public PropertyControlBean myControl;
   
     /**
      * @jpf:action
@@ -49,7 +49,7 @@
     protected Forward begin(){
     	
     	Report report=new Report();
-	DriveClientAccess driver=new DriveClientAccess();
+	DriveGetters driver=new DriveGetters();
 	try{
 		driver.setControl(myControl);
 		report=driver.doTest();

Modified: incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access2/Controller.jpf
==============================================================================
--- incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access2/Controller.jpf	(original)
+++ incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_access2/Controller.jpf	Tue Oct 19 14:36:21 2004
@@ -25,8 +25,8 @@
 import java.beans.Beans;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveClientAccess;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveGetters;
 import org.apache.beehive.test.tools.milton.common.Report;
 
 /* Tests client getting control property via getter/setter on control bean.
@@ -48,11 +48,11 @@
     protected Forward begin(){
     	
     	Report report=new Report();
-	DriveClientAccess driver=new DriveClientAccess();
+	DriveGetters driver=new DriveGetters();
 	try{
-		SinglePropertyBean thebean=(SinglePropertyBean)Beans.instantiate(
+		PropertyControlBean thebean=(PropertyControlBean)Beans.instantiate(
 			Thread.currentThread().getContextClassLoader() ,
-			"org.apache.beehive.controls.test.controls.property.SinglePropertyBean");
+			"org.apache.beehive.controls.test.controls.property.PropertyControlBean");
 		driver.setControl(thebean);
 		report=driver.doTest();
         }

Modified: incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl/Controller.jpf
==============================================================================
--- incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl/Controller.jpf	(original)
+++ incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl/Controller.jpf	Tue Oct 19 14:36:21 2004
@@ -24,8 +24,8 @@
 
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveClientImpl;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveSetters;
 import org.apache.beehive.test.tools.milton.common.Report;
 
 /* Tests getting and setting control property via control context on control implementation
@@ -45,7 +45,7 @@
      * It has a method that allow accessing these property values via control context.
      */
     @Control
-    public SinglePropertyBean myControl;
+    public PropertyControlBean myControl;
 
   
     /**
@@ -57,7 +57,7 @@
     	
     	Report report=new Report();
 	try{
-		DriveClientImpl driver=new DriveClientImpl();
+		DriveSetters driver=new DriveSetters();
 		driver.setControl(myControl);
 		report=driver.doTest();
         }

Modified: incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl2/Controller.jpf
==============================================================================
--- incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl2/Controller.jpf	(original)
+++ incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/client_impl2/Controller.jpf	Tue Oct 19 14:36:21 2004
@@ -25,8 +25,8 @@
 import java.beans.Beans;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveClientImpl;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveSetters;
 import org.apache.beehive.test.tools.milton.common.Report;
 
 /* Tests getting and setting control property via control context on control implementation
@@ -49,11 +49,11 @@
     protected Forward begin(){
     	
     	Report report=new Report();
-    	DriveClientImpl driver =new DriveClientImpl();
+    	DriveSetters driver =new DriveSetters();
 	try{
-		SinglePropertyBean thebean=(SinglePropertyBean)Beans.instantiate(
+		PropertyControlBean thebean=(PropertyControlBean)Beans.instantiate(
 			Thread.currentThread().getContextClassLoader(),
-                	"org.apache.beehive.controls.test.controls.property.SinglePropertyBean");
+                	"org.apache.beehive.controls.test.controls.property.PropertyControlBean");
 		driver.setControl(thebean);
 		report=driver.doTest();
         }

Modified: incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access/Controller.jpf
==============================================================================
--- incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access/Controller.jpf	(original)
+++ incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access/Controller.jpf	Tue Oct 19 14:36:21 2004
@@ -24,8 +24,8 @@
 
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveImplAccess;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveContextAccess;
 import org.apache.beehive.test.tools.milton.common.Report;
 
 /* Tests getting control property via control context on control implementation class
@@ -44,7 +44,7 @@
      * It has a method that allow accessing these property values via control context.
      */
     @Control
-    public SinglePropertyBean myControl;
+    public PropertyControlBean myControl;
 
   
     /**
@@ -56,7 +56,7 @@
     	
     	Report report=new Report();
 	try{
-		DriveImplAccess driver=new DriveImplAccess();
+		DriveContextAccess driver=new DriveContextAccess();
 		driver.setControl(myControl);
 		report=driver.doTest();
         }

Modified: incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access2/Controller.jpf
==============================================================================
--- incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access2/Controller.jpf	(original)
+++ incubator/beehive/trunk/controls/test/webapps/controlsWeb/property/impl_access2/Controller.jpf	Tue Oct 19 14:36:21 2004
@@ -25,8 +25,8 @@
 import java.beans.Beans;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveImplAccess;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveContextAccess;
 import org.apache.beehive.test.tools.milton.common.Report;
 
 /* Tests getting control property via control context on control implmentation
@@ -48,11 +48,11 @@
     protected Forward begin(){
     	
     	Report report=new Report();
-	DriveImplAccess driver=new DriveImplAccess();
+	DriveContextAccess driver=new DriveContextAccess();
 	try{
-		SinglePropertyBean thebean=(SinglePropertyBean)Beans.instantiate(
+		PropertyControlBean thebean=(PropertyControlBean)Beans.instantiate(
 			Thread.currentThread().getContextClassLoader(),
-                	"org.apache.beehive.controls.test.controls.property.SinglePropertyBean");
+                	"org.apache.beehive.controls.test.controls.property.PropertyControlBean");
 		driver.setControl(thebean);
 		report=driver.doTest();
         }
--- incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientImplTest.java	(original)
+++ incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ClientImplTest.java	Tue Oct 19 14:36:21 2004
@@ -1,11 +1,12 @@
 package org.apache.beehive.controls.test.java.property;
 
+
 import junit.framework.TestCase;
 import java.beans.Beans;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.api.bean.ControlBean;
-import org.apache.beehive.controls.test.controls.property.SinglePropertyBean;
-import org.apache.beehive.controls.test.driver.property.DriveClientImpl;
+import org.apache.beehive.controls.test.controls.property.PropertyControlBean;
+import org.apache.beehive.controls.test.driver.property.DriveSetters;
 import org.apache.beehive.test.tools.mantis.annotations.tch.Freq;
 import org.apache.beehive.test.tools.mantis.annotations.tch.Status;
 import org.apache.beehive.test.tools.milton.common.Report;
@@ -20,17 +21,13 @@
     public ClientImplTest( String s ) { super( s ); }
 
  	/**
- 	 * A control that declares some propertySet in its control interface
- 	 * It's sayHello method allows accessing the value via control context.
+ 	 * A control that declares some propertySets in its control interface
 	 */
     @Control
-    public SinglePropertyBean myControl;
-
-
-	/**BUG: getter/setter in generated bean is busted comment out all tests using getter/setter*/
+    public PropertyControlBean myControl;
 
     /**
      * Resets control's property value by setter of the bean instance and
      * retrieves the new value using control context on control's impl.
      * This method instantiates HelloBean by declaration
      */
@@ -40,7 +37,7 @@
     {
 		/*
 		Report report=new Report();
-		DriveClientImpl driver=new DriveClientImpl();
+		DriveSetter driver=new DriveSetter();
 		driver.setControl(myControl);
 		report=driver.doTest();
 		String result=report.getStatus();
@@ -50,7 +47,7 @@
     }
 
     /**
      * Resets control's property value by setter of the bean instance and
      * retrieves the new value using control context on control's impl.
      * This method instantiates HelloBean by program
      */
@@ -58,10 +55,10 @@
     public void testResetPropertyByProgram() throws Exception
     {
 		Report report=new Report();
-		SinglePropertyBean sbean=(SinglePropertyBean)Beans.instantiate(
+		PropertyControlBean sbean=(PropertyControlBean)Beans.instantiate(
 			Thread.currentThread().getContextClassLoader(),
-            "org.apache.beehive.controls.test.controls.property.SinglePropertyBean");
-		DriveClientImpl driver=new DriveClientImpl();
+            "org.apache.beehive.controls.test.controls.property.PropertyControlBean");
+		DriveSetters driver=new DriveSetters();
 		driver.setControl(sbean);
 		report=driver.doTest();
 		String result=report.getStatus();
@@ -20,17 +21,13 @@
 
     /**
-     * Resets control's property value by setter of the bean instance and
+     * Resets control's property value using setters on the bean class and
      * retrieves the new value using control context on control's impl.
      * This method instantiates HelloBean by declaration
@@ -50,7 +47,7 @@
 
     /**
-     * Resets control's property value by setter of the bean instance and
+     * Resets control's property value using setters on the bean class and
      * retrieves the new value using control context on control's impl.
      * This method instantiates HelloBean by program

Modified: incubator/beehive/trunk/controls/test/src/units/org/apache/beehive/controls/test/java/property/ImplAccessTest.java
==============================================================================